@@ -1,7 +1,7 @@
 #' @title Create a table template for plume classes
-#' @description This helper function allows you to generate an empty
-#'   [`tibble`][tibble::tibble()] that you can use as a template to supply
-#'   author data.
+#' @description
+#' Create an empty [tibble][tibble::tibble()] that can be used as a template
+#' to supply author data.
 #' @param minimal If `TRUE`, returns an empty tibble with the following columns:
 #'   `given_name`, `family_name`, `email`, `orcid`, `affiliation` and `note`.
 #'   Otherwise the function returns a template with all columns that can be
@@ -19,18 +19,21 @@
 #' plm_template(role_cols = paste0("role_", 1:5))
 #' @export
 plm_template <- function(minimal = TRUE, role_cols = credit_roles(), credit_roles = FALSE) {
-  check_args("bool", list(minimal, credit_roles))
-  check_character(role_cols, allow_duplicates = FALSE)
+  check_args("bool", quos(minimal, credit_roles))
+  check_character(role_cols, allow("null", "unnamed"))
   if (credit_roles) {
-    print_deprecation("credit_roles", "plm_template", param = "role_cols")
-    role_cols <- credit_roles()
+    lifecycle::deprecate_stop(
+      "0.2.0",
+      "plm_template(credit_roles)",
+      I("`role_cols = credit_roles()`")
+    )
   }
   vars <- get_template_vars(minimal, role_cols)
   tibble(!!!vars, .rows = 0L)
 }
 
 get_template_vars <- function(minimal, role_cols) {
-  vars <- list_fetch_all(.names, "primaries", "orcid", squash = FALSE)
+  vars <- list_fetch(.names, "primaries")
   vars <- c(vars, get_secondaries(minimal), get_nestables())
   vars <- recycle_to_names(NA_character_, vars)
   if (!is.null(role_cols)) {
@@ -41,7 +44,7 @@ get_template_vars <- function(minimal, role_cols) {
 
 get_secondaries <- function(minimal) {
   if (minimal) {
-    return(list(email = "email"))
+    return(list(orcid = "orcid", email = "email"))
   }
   list_fetch(.names, "secondaries")
 }
