@@ -7,10 +7,16 @@ print.plm <- function(x, ...,  sep = "\n") {
 }
 
 as_plm <- function(x) {
-  structure(x, class = c("plm", "character"))
+  add_class(x, "plm")
 }
 
 compare_proxy.plm <- function(x, path = "x") {
   x <- unstructure(x)
   NextMethod()
 }
+
+#' @export
+print.plm_list <- function(x, ...) {
+  print(unclass(x))
+  invisible(x)
+}
