@@ -23,18 +23,17 @@ json_update <- function(old, new) {
 }
 
 as_json <- function(x) {
-  x <- toJSON(x)
-  parse_json(x)
+  x <- jsonlite::toJSON(x)
+  jsonlite::parse_json(x)
 }
 
 separate_yaml_header <- function(x) {
   str_split_1(x, "(?m:^|\\R\\K)-{3}(?:\\R|$)")
 }
 
-yaml_inject <- function(x, lines) {
+yaml_replace <- function(x, lines) {
   yaml <- do.call(yaml::as.yaml, c(list(x), .yaml_args))
-  out <- replace(lines, 2L, yaml)
-  collapse(out, paste0("---", eol()))
+  replace(lines, 2L, yaml)
 }
 
 has_yaml <- function(x) {
@@ -45,7 +44,7 @@ check_has_yaml <- function(x) {
   if (has_yaml(x)) {
     return(invisible())
   }
-  abort_check(msg = c(
+  abort(c(
     "No YAML headers found.",
     i = "YAML headers must be at the beginning of the document.",
     i = "YAML headers must start and end with three hyphens."
@@ -70,11 +69,11 @@ add_yaml_header <- function(x) {
   c("", "", x)
 }
 
-yaml_push <- function(x, file) {
-  UseMethod("yaml_push")
+yaml_update <- function(x, file) {
+  UseMethod("yaml_update")
 }
 
-yaml_push.default <- function(x, file) {
+yaml_update.default <- function(x, file) {
   old <- yaml::read_yaml(file)
   json <- json_update(old, x)
   if (is.null(json)) {
@@ -83,8 +82,8 @@ yaml_push.default <- function(x, file) {
   do.call(yaml::write_yaml, c(list(json), file, .yaml_args))
 }
 
-yaml_push.qmd <- function(x, file) {
-  text <- read_file(file)
+yaml_update.qmd <- function(x, file) {
+  text <- readr::read_file(file)
   check_has_yaml(text)
   items <- separate_yaml_header(text)
   if (yaml_has_strippable(items[[2]])) {
@@ -95,6 +94,7 @@ yaml_push.qmd <- function(x, file) {
   if (is.null(json)) {
     return(invisible())
   }
-  lines <- yaml_inject(json, items)
-  write_lines(lines, file = file, sep = "")
+  lines <- yaml_replace(json, items)
+  lines <- collapse(lines, paste0("---", eol()))
+  readr::write_lines(lines, file = file, sep = "")
 }
