@@ -16,13 +16,13 @@ test_that("get_affiliations/notes() return affiliations/notes", {
     c("1: a", "2: b", "3: c", "4: d")
   )
 
-  aut <- Plume$new(basic_df, symbols = list(affiliation = letters))
+  aut <- Plume$new(basic_df, symbols = plm_symbols(affiliation = letters))
 
   expect_equal(aut$get_affiliations(), c("^a^a", "^b^b", "^c^c", "^d^d"))
   expect_equal(aut$get_notes(), c("^†^a", "^‡^c", "^§^b"))
 })
 
-test_that("get_affiliations/notes() returns `NULL` if no affiliations/notes", {
+test_that("get_affiliations/notes() return `NULL` if no affiliations/notes", {
   aut <- Plume$new(data.frame(
     given_name = "Zip",
     family_name = "Zap",
@@ -33,7 +33,7 @@ test_that("get_affiliations/notes() returns `NULL` if no affiliations/notes", {
 
 # Errors ----
 
-test_that("get_affiliations() give meaningful error messages", {
+test_that("get_affiliations()/get_notes() give meaningful error messages", {
   aut <- Plume$new(basic_df)
 
   expect_snapshot({
@@ -43,13 +43,6 @@ test_that("get_affiliations() give meaningful error messages", {
     (expect_error(
       aut$get_affiliations(superscript = "")
     ))
-  })
-})
-
-test_that("get_notes() give meaningful error messages", {
-  aut <- Plume$new(basic_df)
-
-  expect_snapshot({
     (expect_error(
       aut$get_notes(sep = 1)
     ))
@@ -57,4 +50,15 @@ test_that("get_notes() give meaningful error messages", {
       aut$get_notes(superscript = "")
     ))
   })
+
+  aut <- Plume$new(data.frame(given_name = "A", family_name = "B"))
+
+  expect_snapshot({
+    (expect_error(
+      aut$get_affiliations()
+    ))
+    (expect_error(
+      aut$get_notes()
+    ))
+  })
 })
